Autoclasssumm of Dummy Class without signatures
===============================================

.. autoclasssumm:: dummy.TestClass
    :no-members:
    :autosummary-members:
    :autosummary-nosignatures:
